package at.ac.uibk.gitsearch.web.rest;

import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import org.gitlab4j.api.GitLabApiException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import at.ac.uibk.gitsearch.service.EditorialPagesService;
import at.ac.uibk.gitsearch.service.dto.EditorialPageDTO;

/**
 * REST controller for requesting Pages.
 */
@RestController
@RequestMapping("/api")
public class EditorialPagesResource {

    @SuppressWarnings("unused")
	private final Logger log = LoggerFactory.getLogger(EditorialPagesResource.class);

    private final EditorialPagesService editorialPagesService;

    public EditorialPagesResource(EditorialPagesService editorialPagesService) {
        this.editorialPagesService = editorialPagesService;
    }

    /**
     * {@code GET  /pages} : Get a page from the wiki.
     *
     * @param path the path to the page
     * @throws GitLabApiException, if page is not available
     */
    @GetMapping("/pages")
    public ResponseEntity<EditorialPageDTO> getPage(@RequestParam String path) throws GitLabApiException {
    	
    	EditorialPageDTO  content = editorialPagesService.getContent(path);
        return ResponseEntity.ok().body(content);
    }

    /**
     * {@code GET  /pages/attachment} : Get a page from the wiki.
     *
     * @param path the path to the page
     * @throws GitLabApiException, if page is not available
     */
    @GetMapping(value="/pages/attachment", produces = MediaType.TEXT_PLAIN)
    public ResponseEntity<String> mapPageAttachmentsUrl(@RequestParam String path) throws GitLabApiException {
    	String  content = editorialPagesService.getAttachmentURL(path);
        return ResponseEntity.ok().body(content);
    }
/**
     * {@code DELETE  /page} : Resets the pages cache. Does not really delete all pages
     */
    @DeleteMapping("/pages")
    public void resetPages()  {
    	
    	editorialPagesService.resetCache();
    	
    }


}
