import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';
import { createRequestOption, SearchWithPagination } from 'app/shared/util/request-util';
import { IWatchListEntry } from 'app/shared/model/watch-list-entry.model';

type EntityResponseType = HttpResponse<IWatchListEntry>;
type EntityArrayResponseType = HttpResponse<IWatchListEntry[]>;

@Injectable({ providedIn: 'root' })
export class WatchListEntryService {
  public resourceUrl = SERVER_API_URL + 'api/watch-list-entries';
  public resourceUrlCurrentUser = SERVER_API_URL + 'api/currentuser-watch-list-entries';
  public resourceUrlCurrentUserWL = SERVER_API_URL + 'api/currentuser-watch-lists';
  public resourceSearchUrl = SERVER_API_URL + 'api/_search/watch-list-entries';

  constructor(protected http: HttpClient) {}

  create(watchListEntry: IWatchListEntry): Observable<EntityResponseType> {
    return this.http.post<IWatchListEntry>(this.resourceUrl, watchListEntry, { observe: 'response' });
  }

  createForCurrentUser(watchListEntry: IWatchListEntry): Observable<EntityResponseType> {
    return this.http.post<IWatchListEntry>(this.resourceUrlCurrentUser, watchListEntry, { observe: 'response' });
  }

  deleteForCurrentUser(watchListId: number, exerciseId: string): Observable<HttpResponse<{}>> {
    return this.http.delete(this.resourceUrlCurrentUserWL + '/' + watchListId + '/entries/' + exerciseId, { observe: 'response' });
  }
  update(watchListEntry: IWatchListEntry): Observable<EntityResponseType> {
    return this.http.put<IWatchListEntry>(this.resourceUrl, watchListEntry, { observe: 'response' });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<IWatchListEntry>(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IWatchListEntry[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  search(req: SearchWithPagination): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<IWatchListEntry[]>(this.resourceSearchUrl, { params: options, observe: 'response' });
  }

  getWatchListContent(id: number): Observable<EntityArrayResponseType> {
    return this.http.get<IWatchListEntry[]>(this.resourceUrlCurrentUserWL + '/' + id + '/entries', { observe: 'response' });
  }
}
